@@ -91,7 +91,7 @@ void ActionManager::initPart(KLinkStatusPart* part)
     d->part = part;
     d->actionCollection = part->actionCollection();
 
-    QAction* action = 0;
+    KAction* action = 0;
 
     // *************** File menu *********************
 
@@ -489,7 +489,7 @@ void ActionManager::slotGHNS()
     }
     qDeleteAll(entries);
     
-    kDebug(23100) << "Setting prefered stylesheet: " << lastInstalled;
+    kDebug(23100) << "Setting preferred stylesheet: " << lastInstalled;
     
     KLSConfig::setPreferedStylesheet(lastInstalled);
     KLSConfig::setStylesheetFiles(installedItems);
