@@ -14,38 +14,29 @@
  *                                                                         *
  ***************************************************************************/
 /* KDE INCLUDES */
-#include <klocale.h>
-#include <kiconloader.h>
+#include <ktabwidget.h>
 
 /* QT INCLUDES */
 #include <qstring.h>
 #include <qwidget.h>
 #include <qstringlist.h>
 #include <qevent.h>
-#include <qtabwidget.h>
+//Added by qt3to4:
+#include <QShowEvent>
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
-#include "kommanderplugin.h"
 #include <specials.h>
 #include "tabwidget.h"
 
-enum Functions {
-  FirstFunction = 355,
-  TAB_setTabIcon,
-  LastFunction
-};
-
-TabWidget::TabWidget(QWidget *a_parent, const char *a_name, int a_flags)
-	: QTabWidget(a_parent, a_name, a_flags), KommanderWidget(this)
+TabWidget::TabWidget(QWidget *a_parent, const char *a_name)
+	: KTabWidget(a_parent), KommanderWidget(this)
 {
+  setObjectName(a_name);
   QStringList states;
   states << "default";
   setStates(states);
   setDisplayStates(states);
-
-  KommanderPlugin::setDefaultGroup(Group::DCOP);
-  KommanderPlugin::registerFunction(TAB_setTabIcon, "setTabIcon(QString widget, int Tab, QString Icon)", i18n("Sets an icon on the specified tab. Index is zero based."), 3);
 }
 
 TabWidget::~TabWidget()
@@ -101,28 +92,21 @@ void TabWidget::contextMenuEvent( QContextMenuEvent * e )
 
 bool TabWidget::isFunctionSupported(int f)
 {
-  return f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::insertTab || (f >= FirstFunction && f <= LastFunction) ;
+  return f == DBUS::currentItem || f == DBUS::setCurrentItem || f == DBUS::insertTab;
 }
 
-QString TabWidget::handleDCOP(int function, const QStringList& args)
+QString TabWidget::handleDBUS(int function, const QStringList& args)
 {
   switch (function) {
-    case DCOP::currentItem:
-      return QString::number(currentPageIndex());
-    case DCOP::setCurrentItem:
-      setCurrentPage(args[0].toUInt());
+    case DBUS::currentItem:
+      return QString::number(currentIndex());
+    case DBUS::setCurrentItem:
+      setCurrentIndex(args[0].toInt());
       break;
-    case DCOP::insertTab:
+    case DBUS::insertTab:
       insertTab(0L, args[0], args[1].toUInt());
-      break;
-    case TAB_setTabIcon:
-    {
-      QWidget *w = page(args[0].toInt());
-      setTabIconSet(w, KGlobal::iconLoader()->loadIcon(args[1], KIcon::NoGroup, KIcon::SizeMedium));
-      break;
-    }
     default:
-      return KommanderWidget::handleDCOP(function, args);
+      return KommanderWidget::handleDBUS(function, args);
   }
   return QString();
 }
