@@ -1,20 +1,33 @@
 
-/***************************************************************************
-                          search.c  -  search implementation
-                             -------------------
-    begin                : Fri Nov 2 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
 
+#include "search.h"
 #include "xsldbg.h"
+#include "config-kxsldbg.h"
 #include "debugXSL.h"
 #include "breakpoint.h"
-#include "search.h"
 #include "options.h"
 #include "files.h"
-
 #ifdef __riscos
 
 /* Include for filename conversions */
@@ -42,43 +55,40 @@ static xmlChar searchBuffer[BUFFER_SIZE];
  -------------------------------------------*/
 
 /**
- * findNodeByLineNoHelper:
- * @payload: valid xsltStylesheetPtr
- * @data: valid searchInfoPtr
- * @name: not used
- *
  * We are walking through stylesheets looking for a match 
+ *
+ * @param payload: valid xsltStylesheetPtr
+ * @param data: valid searchInfoPtr
+ * @param name: not used
+ *
  */
-void
-  findNodeByLineNoHelper(void *payload, void *data,
+void findNodeByLineNoHelper(void *payload, void *data,
                          xmlChar * name);
 
 /**
- * globalVarHelper:
- * @payload: valid xsltStylesheetPtr
- * @data: is valid
- * @name: not used
- *
  * Helper to find the global variables. We are given control via
  *   walkStylesheets globalWalkFunc will always be set to the
  *    walkFunc to call
+ *
+ * @param payload: valid xsltStylesheetPtr
+ * @param data: is valid
+ * @param name: not used
+ *
  */
-void
-  globalVarHelper(void **payload, void *data,
+void globalVarHelper(void **payload, void *data,
                   xmlChar * name);
 
 /**
- * localVarHelper:
- * @payload: valid xsltTemplatePtr
- * @data: is valid
- * @name: not used
- *
  * Helper to find the local variables. We are given control via walkTemplates
  *    globalWalkFunc will always be set to the walkFunc to call
  *   localWalkFunc will always be set to the walkFunc to call
+ *
+ * @param payload: valid xsltTemplatePtr
+ * @param data: is valid
+ * @parm name: not used
+ *
  */
-void
-  localVarHelper(void **payload, void *data,
+void localVarHelper(void **payload, void *data,
                  xmlChar * name);
 
 
@@ -87,17 +97,7 @@ void
     ---------------------------------------*/
 
 
-/**
- * searchInit:
- *
- * Initialize the search module
- *
- * Returns 1 if search structures have been initialized properly and all
- *               memory required has been obtained,
- *         0 otherwise
-*/
-int
-searchInit(void)
+int searchInit(void)
 {
     searchDataBase = NULL;
     searchDataBaseRoot = NULL;
@@ -109,13 +109,7 @@ searchInit(void)
 }
 
 
-/**
- * searchFree:
- *
- * Free all memory used by the search module
- */
-void
-searchFree(void)
+void searchFree(void)
 {
     if (searchDataBase) {
         xmlFreeDoc(searchDataBase);
@@ -125,17 +119,7 @@ searchFree(void)
 }
 
 
-/**
- * searchNewInfo:
- * @type: What type of search is required
- * 
- * Create a new search
- *
- * Returns A valid search info pointer if successful
- *         NULL otherwise
- */
-searchInfoPtr
-searchNewInfo(SearchEnum type)
+searchInfoPtr searchNewInfo(SearchEnum type)
 {
     searchInfoPtr result = NULL;
     int searchType = type;
@@ -216,14 +200,7 @@ searchNewInfo(SearchEnum type)
 }
 
 
-/**
- * searchFreeInfo:
- * @info: valid search info
- *
- * Free memory used by @info
- */
-void
-searchFreeInfo(searchInfoPtr info)
+void searchFreeInfo(searchInfoPtr info)
 {
     if (info) {
         if (info->data) {
@@ -286,16 +263,7 @@ searchFreeInfo(searchInfoPtr info)
 }
 
 
-/**
- * searchEmpty:
- *
- * Empty the seach dataBase of its contents
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-searchEmpty(void)
+int searchEmpty(void)
 {
     if (searchDataBase) {
         xmlFreeDoc(searchDataBase);
@@ -325,49 +293,19 @@ searchEmpty(void)
 }
 
 
-/**
- * searchDoc:
- *
- * Return the document used for seaching ie the search dataBase
- *
- * Returns The document used for searching
- *         Dangerous function to use! Does NOT return a copy of 
- *             search data  so don't free it
- */
-xmlDocPtr
-searchDoc(void)
+xmlDocPtr searchDoc(void)
 {
     return searchDataBase;
 }
 
 
-/**
- * searchRootNode:
- *
- * Get the topmost node in the search dataBase
- *
- * Returns The topmost xml node in search dataBase.
- *         Dangerous function to use! Does NOT return a copy of 
- *             search root node  so don't free it
- */
-xmlNodePtr
-searchRootNode(void)
+xmlNodePtr searchRootNode(void)
 {
     return searchDataBaseRoot;
 }
 
 
-/**
- * searchAdd:
- * @node: Is valid
- *
- * Add a node to the search dataBase
- *
- * Returns 1 if able to add @node to top node in search dataBase,
- *         0 otherwise
- */
-int
-searchAdd(xmlNodePtr node)
+int searchAdd(xmlNodePtr node)
 {
     int result = 0;
 
@@ -380,137 +318,94 @@ searchAdd(xmlNodePtr node)
 }
 
 
-/**
- * searchSave:
- * @fileName: A valid file name, or NULL for the default
- *
- * Save the search dataBase to @fileName
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-searchSave(const xmlChar * fileName)
+int searchSave(const xmlChar * fileName)
 {
 
     int result = 0;
-    xmlChar *searchInput = NULL;
+    QString searchInput;
 
     if (fileName == NULL)
         searchInput = filesSearchFileName(FILES_SEARCHINPUT);
     else
-        searchInput = xmlStrdup(fileName);
+        searchInput = xsldbgText(fileName);
 
-    if (xmlSaveFormatFile((char *) searchInput, searchDataBase, 1) != -1){
+    if (xmlSaveFormatFile(searchInput.toUtf8().constData(), searchDataBase, 1) != -1){
         result = 1;
     }else{
-        xsldbgGenericErrorFunc(i18n("Error: Unable to write search Database to file %1. Try setting the \"searchresultspath\" option to a writable path.\n").arg(xsldbgText(searchInput)));
+        xsldbgGenericErrorFunc(i18n("Error: Unable to write search Database to file %1. Try setting the \"searchresultspath\" option to a writable path.\n", searchInput));
     }
 
-    if (searchInput)
-        xmlFree(searchInput);
 
     return result;
 }
 
 
-/**
- * searchQuery:
- * @query: The query to run . If NULL then query is "//search/ *"
- * @tempFile: Where do we load the search dataBase from to execute
- *             query. If tempFile is NULL "searchresult.xml" is used
- * @outputFile : Where do we store the result. If NULL
- *             then default to  "searchresult.html"
- * 
- * Send query as parameter for execution of search.xsl using
- *    data stored in @tempFile 
- *
- * Returns 1 on success,
- *         0 otherwise   
- */
-int
-searchQuery(const xmlChar * tempFile, const xmlChar * outputFile,
+int searchQuery(const xmlChar * tempFile, const xmlChar * outputFile,
             const xmlChar * query)
 {
     int result = 0;
 
-    /* The file name of where the input is comming from */
-    xmlChar *searchInput = NULL;
+    /* The file name of where the input is coming from */
+    QString searchInput;
 
     /* The XSL file name to use during transformation of searchInput */
-    xmlChar *searchXSL = NULL;
+    QString searchXSL;
 
     /* Where to store the result of transformation */
-    xmlChar *searchOutput = NULL;
+    QString searchOutput;
 
 
-    /* if a tempFile if provided its up you to make sure that it is correct !! */
+    /* if a tempFile is provided it is up to you to make sure that it is correct !! */
     if (tempFile == NULL)
         searchInput = filesSearchFileName(FILES_SEARCHINPUT);
     else
-        searchInput = xmlStrdup(tempFile);
+        searchInput = xsldbgText(tempFile);
 
     searchXSL = filesSearchFileName(FILES_SEARCHXSL);
 
-    /* if a outputFile if provided its up you to make sure that it is correct */
+    /* if an outputFile is provided it is up to you to make sure that it is correct */
     if (outputFile == NULL)
         searchOutput = filesSearchFileName(FILES_SEARCHRESULT);
     else
-        searchOutput = xmlStrdup(outputFile);
+        searchOutput = xsldbgText(outputFile);
 
     if (!query || (xmlStrlen(query) == 0))
         query = (xmlChar *) "--param query //search/*";
 
     /* see configure.in for the definition of XSLDBG_BIN, the name of our binary */
-    if (searchInput && searchXSL && searchOutput) {
+    if (!searchInput.isEmpty() && !searchXSL.isEmpty() && !searchOutput.isEmpty()) {
         if (optionsGetIntOption(OPTIONS_CATALOGS) == 0)
             snprintf((char *) searchBuffer, sizeof(searchBuffer),
                      "%s -o %s %s %s %s", XSLDBG_BIN,
-                     searchOutput, query, searchXSL, searchInput);
+                     searchOutput.toUtf8().constData(),
+                     query,
+                     searchXSL.toUtf8().constData(),
+                     searchInput.toUtf8().constData());
         else
             /* assume that we are to use catalogs as well in our query */
             snprintf((char *) searchBuffer, sizeof(searchBuffer),
                      "%s --catalogs -o %s %s %s %s", XSLDBG_BIN,
-                     searchOutput, query, searchXSL, searchInput);
+                     searchOutput.toUtf8().constData(),
+                     query,
+                     searchXSL.toUtf8().constData(),
+                     searchInput.toUtf8().constData());
         result = xslDbgShellExecute(searchBuffer, 1);
 
         if (result && (optionsGetIntOption(OPTIONS_PREFER_HTML) == 0)) {
             /* try printing out the file */
-            result = filesMoreFile(searchOutput, NULL);
+            result = filesMoreFile((const xmlChar*)searchOutput.toUtf8().constData(), NULL);
         }
 
-        xsldbgGenericErrorFunc(i18n("Information: Transformed %1 using %2 and saved to %3.\n").arg(xsldbgText(searchInput)).arg(xsldbgText(searchXSL)).arg(xsldbgText(searchOutput)));
+        xsldbgGenericErrorFunc(i18n("Information: Transformed %1 using %2 and saved to %3.\n", searchInput, searchXSL, searchOutput));
     } else {
-        xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to command %1.\n").arg("search"));
+        xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to command %1.\n", QString("search")));
     }
 
-    if (searchInput)
-        xmlFree(searchInput);
-
-    if (searchXSL)
-        xmlFree(searchXSL);
-
-    if (searchOutput)
-        xmlFree(searchOutput);
-
     return result;
 }
 
 
-/**
- * scanForBreakPoint: 
- * @payload: A valid breakPointPtr 
- * @data: The criteria to look for and a valid searchInfoPtr of
- *          type SEARCH_BREAKPOINT 
- * @name: Not used 
- *
- * Test if break point matches criteria given by @data. If so then 
- *      set @data->found to 1 and stores  reference to break point found in 
- *         @data->data->node
- *     otherwise @data is unchanged
-*/
-void
-scanForBreakPoint(void *payload, void *data,
+void scanForBreakPoint(void *payload, void *data,
                   xmlChar * name)
 {
     Q_UNUSED(name);
@@ -540,19 +435,7 @@ scanForBreakPoint(void *payload, void *data,
 
 
 
-/**
- * scanForNode: 
- * @payload: A valid xmlNodePtr
- * @data: The criteria to look for and a valid searchInfo of
- *          type SEARCH_NODE 
- * @name: Not used
-
- * Test if node matches criteria given by @data if so then set @data->found 
- *   to 1 and  stores reference to node found in @data->data->node
- *     otherwise @data is unchanged
- */
-void
-scanForNode(void *payload, void *data, xmlChar * name)
+void scanForNode(void *payload, void *data, xmlChar * name)
 {
     Q_UNUSED(name);
     searchInfoPtr searchInf = (searchInfoPtr) data;
@@ -587,16 +470,7 @@ scanForNode(void *payload, void *data, xmlChar * name)
 }
 
 
-/**
- * findNodeByLineNoHelper:
- * @payload: A valid xsltStylesheetPtr
- * @data: A valid searchInfoPtr
- * @name: Not used
- *
- * We are walking through stylesheets looking for a match 
- */
-void
-findNodeByLineNoHelper(void *payload, void *data,
+void findNodeByLineNoHelper(void *payload, void *data,
                        xmlChar * name)
 {
     Q_UNUSED(name);
@@ -615,19 +489,7 @@ findNodeByLineNoHelper(void *payload, void *data,
 }
 
 
-/**
- * findNodeByLineNo:
- * @ctxt: Valid ctxt to look into
- * @url: Non-null, non-empty file name that has been loaded by debugger
- * @lineNumber: @lineNumber >= 0 and is available in @url
- *
- * Finds the closest line number in file specified that can be a point 
- *
- * Returns The node at line number number specified if successfull,
- *          NULL otherwise
- */
-xmlNodePtr
-findNodeByLineNo(xsltTransformContextPtr ctxt,
+xmlNodePtr findNodeByLineNo(xsltTransformContextPtr ctxt,
                  const xmlChar * url, long lineNumber)
 {
     xmlNodePtr result = NULL;
@@ -672,18 +534,7 @@ findNodeByLineNo(xsltTransformContextPtr ctxt,
 }
 
 
-/**
- * findTemplateNode: 
- * @style: A valid stylesheet collection to look into 
- * @name: A valid template name to look for
- *
- * Find a template node
- *
- * Returns The template node found if successful,
- *         NULL otherwise 
- */
-xmlNodePtr
-findTemplateNode(xsltStylesheetPtr style, const xmlChar * name)
+xmlNodePtr findTemplateNode(xsltStylesheetPtr style, const xmlChar * name)
 {
     xmlNodePtr result = NULL;
     xmlChar *templName;
@@ -720,23 +571,12 @@ findTemplateNode(xsltStylesheetPtr style, const xmlChar * name)
     }
 
     if (!result)
-        xsldbgGenericErrorFunc(i18n("Error: XSLT template named \"%1\" was not found.\n").arg(xsldbgText(name)));
+        xsldbgGenericErrorFunc(i18n("Error: XSLT template named \"%1\" was not found.\n", xsldbgText(name)));
     return result;
 }
 
 
-/**
- * findBreakPointByName:
- * @templateName: The template name to look for
- *
- * Find the breakpoint at template with "match" or "name" equal 
- *    to templateName
- *
- * Returns The break point that matches @templateName
- *         NULL otherwise
-*/
-breakPointPtr
-findBreakPointByName(const xmlChar * templateName)
+breakPointPtr findBreakPointByName(const xmlChar * templateName)
 {
     breakPointPtr result = NULL;
     searchInfoPtr searchInf = searchNewInfo(SEARCH_BREAKPOINT);
@@ -765,17 +605,7 @@ findBreakPointByName(const xmlChar * templateName)
 }
 
 
-/**
- * findBreakPointById:
- * @id: The break point id to look for
- *
- * Find a break point by its id
- *
- * Returns The break point with given the break point id if found,
- *         NULL otherwise 
- */
-breakPointPtr
-findBreakPointById(int id)
+breakPointPtr findBreakPointById(int id)
 {
     breakPointPtr result = NULL;
     searchInfoPtr searchInf = searchNewInfo(SEARCH_BREAKPOINT);
@@ -802,17 +632,7 @@ findBreakPointById(int id)
 }
 
 
-/**
- * findNodesByQuery:
- * @query: The xpath query to run, see docs/en/search.dtd for more details
- *  
- * Find nodes in search dataBase using an xpath query
- *
- * Returns The nodes that match the given query on success,
- *         NULL otherwise 
- */
-xmlXPathObjectPtr
-findNodesByQuery(const xmlChar * query)
+xmlXPathObjectPtr findNodesByQuery(const xmlChar * query)
 {
     Q_UNUSED(query);
     xmlXPathObjectPtr list = NULL;
@@ -822,16 +642,7 @@ findNodesByQuery(const xmlChar * query)
 
 
 
-/**
- * walkBreakPoints:
- * @walkFunc: The function to callback for each break point found
- * @data: The extra data to pass onto walkFunc
- *
- * Walks through all break points calling walkFunc for each. The payload
- *  sent to walkFunc is of type breakPointPtr 
- */
-void
-walkBreakPoints(xmlHashScanner walkFunc, void *data)
+void walkBreakPoints(xmlHashScanner walkFunc, void *data)
 {
     int lineNo;
     xmlHashTablePtr hashTable;
@@ -848,17 +659,7 @@ walkBreakPoints(xmlHashScanner walkFunc, void *data)
 }
 
 
-/**
- * walkTemplates:
- * @walkFunc: The function to callback for each template found
- * @data: The extra data to pass onto walkFunc
- * @style: The stylesheet to start from
- *
- * Walks through all templates calling walkFunc for each. The payload
- *   of walkFunc is of type xsltTemplatePtr
- */
-void
-walkTemplates(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
+void walkTemplates(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
 {
     xsltTemplatePtr templ;
 
@@ -879,17 +680,7 @@ walkTemplates(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
 }
 
 
-/**
- * walkStylesheets:
- * @walkFunc: The function to callback for each stylesheet found
- * @data: The extra data to pass onto walkFunc
- * @style: The stylesheet to start from
- *
- * Walks through all templates calling walkFunc for each. The payload
- *   sent to walkFunc is of type xsltStylesheetPtr
- */
-void
-walkStylesheets(xmlHashScanner walkFunc, void *data,
+void walkStylesheets(xmlHashScanner walkFunc, void *data,
                 xsltStylesheetPtr style)
 {
     xsltStylesheetPtr next;
@@ -911,18 +702,7 @@ walkStylesheets(xmlHashScanner walkFunc, void *data,
 
 xmlHashScanner globalWalkFunc = NULL;
 
-/**
- * globalVarHelper:
- * @payload: valid xsltStylesheetPtr
- * @data: is valid
- * @name: not used
- *
- * Helper to find the global variables. We are given control via
- *   walkStylesheets globalWalkFunc will always be set to the
- *    walkFunc to call
- */
-void
-globalVarHelper(void **payload, void *data,
+void globalVarHelper(void **payload, void *data,
                 xmlChar * name)
 {
     Q_UNUSED(data);
@@ -941,17 +721,7 @@ globalVarHelper(void **payload, void *data,
 }
 
 
-/**
- * walkGlobals:
- * @walkFunc: The function to callback for each gobal variable found
- * @data: The extra data to pass onto walkFunc
- * @style: The stylesheet to start from
- *
- * Call walkFunc for each global variable. The payload
- *   sent to walkFunc is of type  xmlNodePtr
- */
-void
-walkGlobals(xmlHashScanner walkFunc, void *data,
+void walkGlobals(xmlHashScanner walkFunc, void *data,
             xsltStylesheetPtr style)
 {
     Q_UNUSED(data);
@@ -967,18 +737,7 @@ walkGlobals(xmlHashScanner walkFunc, void *data,
 
 xmlHashScanner localWalkFunc = NULL;
 
-/**
- * localVarHelper:
- * @payload: valid xsltTemplatePtr
- * @data: is valid
- * @name: not used
- *
- * Helper to find the local variables. We are given control via walkTemplates
- *    globalWalkFunc will always be set to the walkFunc to call
- *   localWalkFunc will always be set to the walkFunc to call
- */
-void
-localVarHelper(void **payload, void *data,
+void localVarHelper(void **payload, void *data,
                xmlChar * name)
 {
     Q_UNUSED(data);
@@ -1001,17 +760,7 @@ localVarHelper(void **payload, void *data,
 }
 
 
-/**
- * walkLocals:
- * @walkFunc: The function to callback for each local variable found
- * @data: The extra data to pass onto walkFunc
- * @style: The stylesheet to start from
- *
- * Walks through all local variables calling walkFunc for each. The payload
- *   of walkFunc is of type xmlNodePtr
- */
-void
-walkLocals(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
+void walkLocals(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
 {
     if (!walkFunc || !style)
         return;
@@ -1023,18 +772,8 @@ walkLocals(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
 }
 
 
-/**
- * walkIncludes:
- * @walkFunc: The function to callback for each included stylesheet
- * @data: The extra data to pass onto walkFunc
- * @style: The stylesheet to start from
- *
- * Walks through all included stylesheets calling walkFunc for each. 
- * The payload of walkFunc is of type xmlNodePtr
- */
 
-void
-walkIncludes(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
+void walkIncludes(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
 {
     xsltDocumentPtr document;   /* included xslt documents */
 
@@ -1057,17 +796,7 @@ walkIncludes(xmlHashScanner walkFunc, void *data, xsltStylesheetPtr style)
 }
 
 
-/**
- * walkIncludeInst:
- * @walkFunc: The function to callback for each xsl:include instruction found
- * @data: The extra data to pass onto walkFunc
- * @style: The stylesheet to start from
- *
- * Walks through all xsl:include calling walkFunc for each. The payload
- *   of walkFunc is of type xmlNodePtr
- */
-void
-walkIncludeInst(xmlHashScanner walkFunc, void *data,
+void walkIncludeInst(xmlHashScanner walkFunc, void *data,
                 xsltStylesheetPtr style)
 {
     xmlNodePtr node = NULL, styleChild = NULL;
@@ -1105,17 +834,7 @@ walkIncludeInst(xmlHashScanner walkFunc, void *data,
 }
 
 
-/**
- * walkChildNodes:
- * @walkFunc: The function to callback for each child/sibling found
- * @data: The extra data to pass onto walkFunc
- * @node: Is valid
- *
- * Call walkFunc for each child of @node the payload sent to walkFunc is
- *   a xmlNodePtr
- */
-void
-walkChildNodes(xmlHashScanner walkFunc, void *data, xmlNodePtr node)
+void walkChildNodes(xmlHashScanner walkFunc, void *data, xmlNodePtr node)
 {
     xmlNodePtr child = NULL;
     searchInfoPtr searchInf = (searchInfoPtr) data;
@@ -1134,18 +853,7 @@ walkChildNodes(xmlHashScanner walkFunc, void *data, xmlNodePtr node)
 }
 
 
-/**
- * searchBreakPointNode:
- * @breakPtr: Is valid
- *
- * Convert @breakPtr into search dataBase format
- *
- * Returns @breakPtr as a new xmlNode in search dataBase format 
- *               if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchBreakPointNode(breakPointPtr breakPtr)
+xmlNodePtr searchBreakPointNode(breakPointPtr breakPtr)
 {
 
     xmlNodePtr node = NULL;
@@ -1195,18 +903,7 @@ searchBreakPointNode(breakPointPtr breakPtr)
 }
 
 
-/**
- * searchTemplateNode:
- * @templNode: Is valid
- * 
- * Convert @templateNode into search dataBase format
- *
- * Returns @templNode as a new xmlNode in search dataBase format 
- *               if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchTemplateNode(xmlNodePtr templNode)
+xmlNodePtr searchTemplateNode(xmlNodePtr templNode)
 {
     xmlNodePtr node = NULL;
     xmlChar *value;
@@ -1258,18 +955,7 @@ searchTemplateNode(xmlNodePtr templNode)
 }
 
 
-/** 
- * searchGlobalNode:
- * @globalVariable: Is valid
- *
- * Convert @globalVariable into search dataBase format
- *
- * Returns @globalVariable as a new xmlNode in search dataBase format 
- *             if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchGlobalNode(xmlNodePtr variable)
+xmlNodePtr searchGlobalNode(xmlNodePtr variable)
 {
     xmlNodePtr node = NULL;
     int result = 1;
@@ -1318,18 +1004,7 @@ searchGlobalNode(xmlNodePtr variable)
 }
 
 
-/** 
- * searchLocalNode:
- * @localvariable: Is valid
- *
- * Convert @localVariable into search dataBase format
- *
- * Returns @localVariable as a new xmlNode in search dataBase format 
- *             if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchLocalNode(xmlNodePtr variable)
+xmlNodePtr searchLocalNode(xmlNodePtr variable)
 {
     xmlNodePtr node = NULL;
     int result = 1;
@@ -1370,17 +1045,7 @@ searchLocalNode(xmlNodePtr variable)
 }
 
 
-/**
- * searchSourceNode:
- * @style: Is valid
- * 
- * Convert @style into search dataBase format
- *
- * Returns @style as a new xmlNode in search dataBase format if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchSourceNode(xsltStylesheetPtr style)
+xmlNodePtr searchSourceNode(xsltStylesheetPtr style)
 {
     xmlNodePtr node = NULL;
     int result = 1;
@@ -1418,17 +1083,7 @@ searchSourceNode(xsltStylesheetPtr style)
 }
 
 
-/**
- * searchIncludeNode:
- * @include: Is a valid xsl:include instruction
- *   
- * Convert @include into search dataBase format
- *
- * Returns @include as a new xmlNode in search dataBase format if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchIncludeNode(xmlNodePtr include)
+xmlNodePtr searchIncludeNode(xmlNodePtr include)
 {
     xmlNodePtr node = NULL;
     int result = 1;
@@ -1472,18 +1127,7 @@ searchIncludeNode(xmlNodePtr include)
 }
 
 
-/**
- * searchCallStackNode:
- * @callStackItem: Is valid
- * 
- * Convert @callStackItem into search dataBase format
- *
- * Returns @callStackItem as a new xmlNode in search dataBase format 
- *            if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchCallStackNode(callPointPtr callStackItem)
+xmlNodePtr searchCallStackNode(callPointPtr callStackItem)
 {
     xmlNodePtr node = NULL;
     int result = 1;
@@ -1521,12 +1165,11 @@ searchCallStackNode(callPointPtr callStackItem)
 
 static xmlChar *commentText(xmlNodePtr node);
 
-/*
+/**
  * Returns A copy of comment text that applies to node,
  *         NULL otherwise
  */
-xmlChar *
-commentText(xmlNodePtr node)
+xmlChar * commentText(xmlNodePtr node)
 {
     xmlChar *result = NULL;
 
@@ -1538,19 +1181,8 @@ commentText(xmlNodePtr node)
     return result;
 }
 
-/**
- * searchCommentNode:
- * @sourceNode: Is valid
- * 
- * Find documentation comment that applies to @node. If found convert comment 
- *         into search dataBase format required
- *
- * Returns Documentation comment for @node as a new xmlNode in search dataBase format 
- *            if successful,
- *         NULL otherwise
- */
-xmlNodePtr
-searchCommentNode(xmlNodePtr sourceNode)
+
+xmlNodePtr searchCommentNode(xmlNodePtr sourceNode)
 {
     xmlNodePtr node = NULL, textChild = NULL;
     xmlChar *text = NULL;
